Enum bitflags::__core::env::VarError 1.0.0
[−]
[src]
pub enum VarError {
NotPresent,
NotUnicode(OsString),
}1.0.0
Possible errors from the env::var method.
Variants
NotPresent | The specified environment variable was not present in the current process's environment. | |
NotUnicode | The specified environment variable was found, but it did not contain valid unicode data. The found data is returned as a payload of this variant. |