Struct bitflags::__core::ffi::NulError 1.0.0
[−]
[src]
pub struct NulError(_, _);
An error returned from CString::new to indicate that a nul byte was found
in the vector provided.
Methods
impl NulError
fn nul_position(&self) -> usize
Returns the position of the nul byte in the slice that was provided to
CString::new.
fn into_vec(self) -> Vec<u8>
Consumes this error, returning the underlying vector of bytes which generated the error in the first place.