Enum bitflags::__core::net::Shutdown 1.0.0
[−]
[src]
pub enum Shutdown {
Read,
Write,
Both,
}1.0.0
Possible values which can be passed to the shutdown method of TcpStream.
Variants
Read | Indicates that the reading portion of this stream/socket should be shut
down. All currently blocked and future reads will return | |
Write | Indicates that the writing portion of this stream/socket should be shut down. All currently blocked and future writes will return an error. | |
Both | Shut down both the reading and writing portions of this stream. See |