Enum bitflags::__core::path::Prefix 1.0.0
[−]
[src]
pub enum Prefix<'a> {
Verbatim(&'a OsStr),
VerbatimUNC(&'a OsStr, &'a OsStr),
VerbatimDisk(u8),
DeviceNS(&'a OsStr),
UNC(&'a OsStr, &'a OsStr),
Disk(u8),
}Path prefixes (Windows only).
Windows uses a variety of path styles, including references to drive
volumes (like C:), network shared folders (like \\server\share) and
others. In addition, some path prefixes are "verbatim", in which case
/ is not treated as a separator and essentially no normalization is
performed.
Variants
Verbatim | Prefix | |
VerbatimUNC | Prefix | |
VerbatimDisk | Prefix like | |
DeviceNS | Prefix | |
UNC | Prefix | |
Disk | Prefix |
Methods
impl<'a> Prefix<'a>
fn is_verbatim(&self) -> bool
Determines if the prefix is verbatim, i.e. begins with \\?\.