Struct bitflags::__core::path::PathBuf1.0.0 [] [src]

pub struct PathBuf {
    // some fields omitted
}

An owned, mutable path (akin to String).

This type provides methods like push and set_extension that mutate the path in place. It also implements Deref to Path, meaning that all methods on Path slices are available on PathBuf values as well.

More details about the overall approach can be found in the module documentation.

Examples

use std::path::PathBuf;

let mut path = PathBuf::from("c:\\");
path.push("windows");
path.push("system32");
path.set_extension("dll");

Methods

impl PathBuf

fn new() -> PathBuf

Allocates an empty PathBuf.

fn as_path(&self) -> &Path

Coerces to a Path slice.

fn push<P>(&mut self, path: P) where P: AsRef<Path>

Extends self with path.

If path is absolute, it replaces the current path.

On Windows:

  • if path has a root but no prefix (e.g. \windows), it replaces everything except for the prefix (if any) of self.
  • if path has a prefix but no root, it replaces self.

Examples

use std::path::PathBuf;

let mut path = PathBuf::new();
path.push("/tmp");
path.push("file.bk");
assert_eq!(path, PathBuf::from("/tmp/file.bk"));

// Pushing an absolute path replaces the current path
path.push("/etc/passwd");
assert_eq!(path, PathBuf::from("/etc/passwd"));

fn pop(&mut self) -> bool

Truncate self to self.parent().

Returns false and does nothing if self.file_name() is None. Otherwise, returns true.

fn set_file_name<S>(&mut self, file_name: S) where S: AsRef<OsStr>

Updates self.file_name() to file_name.

If self.file_name() was None, this is equivalent to pushing file_name.

Examples

use std::path::PathBuf;

let mut buf = PathBuf::from("/");
assert!(buf.file_name() == None);
buf.set_file_name("bar");
assert!(buf == PathBuf::from("/bar"));
assert!(buf.file_name().is_some());
buf.set_file_name("baz.txt");
assert!(buf == PathBuf::from("/baz.txt"));

fn set_extension<S>(&mut self, extension: S) -> bool where S: AsRef<OsStr>

Updates self.extension() to extension.

If self.file_name() is None, does nothing and returns false.

Otherwise, returns true; if self.extension() is None, the extension is added; otherwise it is replaced.

fn into_os_string(self) -> OsString

Consumes the PathBuf, yielding its internal OsString storage.

Methods from Deref<Target=Path>

fn as_os_str(&self) -> &OsStr

Yields the underlying OsStr slice.

Examples

use std::path::Path;

let os_str = Path::new("foo.txt").as_os_str();
assert_eq!(os_str, std::ffi::OsStr::new("foo.txt"));

fn to_str(&self) -> Option<&str>

Yields a &str slice if the Path is valid unicode.

This conversion may entail doing a check for UTF-8 validity.

Examples

use std::path::Path;

let path_str = Path::new("foo.txt").to_str();
assert_eq!(path_str, Some("foo.txt"));

fn to_string_lossy(&self) -> Cow<str>

Converts a Path to a Cow<str>.

Any non-Unicode sequences are replaced with U+FFFD REPLACEMENT CHARACTER.

Examples

use std::path::Path;

let path_str = Path::new("foo.txt").to_string_lossy();
assert_eq!(path_str, "foo.txt");

fn to_path_buf(&self) -> PathBuf

Converts a Path to an owned PathBuf.

Examples

use std::path::Path;

let path_buf = Path::new("foo.txt").to_path_buf();
assert_eq!(path_buf, std::path::PathBuf::from("foo.txt"));

fn is_absolute(&self) -> bool

A path is absolute if it is independent of the current directory.

  • On Unix, a path is absolute if it starts with the root, so is_absolute and has_root are equivalent.

  • On Windows, a path is absolute if it has a prefix and starts with the root: c:\windows is absolute, while c:temp and \temp are not. In other words, path.is_absolute() == path.prefix().is_some() && path.has_root().

Examples

use std::path::Path;

assert!(!Path::new("foo.txt").is_absolute());

fn is_relative(&self) -> bool

A path is relative if it is not absolute.

Examples

use std::path::Path;

assert!(Path::new("foo.txt").is_relative());

fn has_root(&self) -> bool

A path has a root if the body of the path begins with the directory separator.

  • On Unix, a path has a root if it begins with /.

  • On Windows, a path has a root if it:

    • has no prefix and begins with a separator, e.g. \\windows
    • has a prefix followed by a separator, e.g. c:\windows but not c:windows
    • has any non-disk prefix, e.g. \\server\share

Examples

use std::path::Path;

assert!(Path::new("/etc/passwd").has_root());

fn parent(&self) -> Option<&Path>

The path without its final component, if any.

Returns None if the path terminates in a root or prefix.

Examples

use std::path::Path;

let path = Path::new("/foo/bar");
let parent = path.parent().unwrap();
assert_eq!(parent, Path::new("/foo"));

let grand_parent = parent.parent().unwrap();
assert_eq!(grand_parent, Path::new("/"));
assert_eq!(grand_parent.parent(), None);

fn file_name(&self) -> Option<&OsStr>

The final component of the path, if it is a normal file.

If the path terminates in ., .., or consists solely of a root of prefix, file_name will return None.

Examples

use std::path::Path;
use std::ffi::OsStr;

let path = Path::new("foo.txt");
let os_str = OsStr::new("foo.txt");

assert_eq!(Some(os_str), path.file_name());

fn strip_prefix<P>(&'a self, base: &'a P) -> Result<&'a Path, StripPrefixError> where P: AsRef<Path> + ?Sized
1.7.0

Returns a path that, when joined onto base, yields self.

Errors

If base is not a prefix of self (i.e. starts_with returns false), returns Err.

fn starts_with<P>(&self, base: P) -> bool where P: AsRef<Path>

Determines whether base is a prefix of self.

Only considers whole path components to match.

Examples

use std::path::Path;

let path = Path::new("/etc/passwd");

assert!(path.starts_with("/etc"));

assert!(!path.starts_with("/e"));

fn ends_with<P>(&self, child: P) -> bool where P: AsRef<Path>

Determines whether child is a suffix of self.

Only considers whole path components to match.

Examples

use std::path::Path;

let path = Path::new("/etc/passwd");

assert!(path.ends_with("passwd"));

fn file_stem(&self) -> Option<&OsStr>

Extracts the stem (non-extension) portion of self.file_name().

The stem is:

  • None, if there is no file name;
  • The entire file name if there is no embedded .;
  • The entire file name if the file name begins with . and has no other .s within;
  • Otherwise, the portion of the file name before the final .

Examples

use std::path::Path;

let path = Path::new("foo.rs");

assert_eq!("foo", path.file_stem().unwrap());

fn extension(&self) -> Option<&OsStr>

Extracts the extension of self.file_name(), if possible.

The extension is:

  • None, if there is no file name;
  • None, if there is no embedded .;
  • None, if the file name begins with . and has no other .s within;
  • Otherwise, the portion of the file name after the final .

Examples

use std::path::Path;

let path = Path::new("foo.rs");

assert_eq!("rs", path.extension().unwrap());

fn join<P>(&self, path: P) -> PathBuf where P: AsRef<Path>

Creates an owned PathBuf with path adjoined to self.

See PathBuf::push for more details on what it means to adjoin a path.

Examples

use std::path::{Path, PathBuf};

assert_eq!(Path::new("/etc").join("passwd"), PathBuf::from("/etc/passwd"));

fn with_file_name<S>(&self, file_name: S) -> PathBuf where S: AsRef<OsStr>

Creates an owned PathBuf like self but with the given file name.

See PathBuf::set_file_name for more details.

Examples

use std::path::{Path, PathBuf};

let path = Path::new("/tmp/foo.txt");
assert_eq!(path.with_file_name("bar.txt"), PathBuf::from("/tmp/bar.txt"));

fn with_extension<S>(&self, extension: S) -> PathBuf where S: AsRef<OsStr>

Creates an owned PathBuf like self but with the given extension.

See PathBuf::set_extension for more details.

Examples

use std::path::{Path, PathBuf};

let path = Path::new("foo.rs");
assert_eq!(path.with_extension("txt"), PathBuf::from("foo.txt"));

fn components(&self) -> Components

Produce an iterator over the components of the path.

Examples

use std::path::{Path, Component};
use std::ffi::OsStr;

let mut components = Path::new("/tmp/foo.txt").components();

assert_eq!(components.next(), Some(Component::RootDir));
assert_eq!(components.next(), Some(Component::Normal(OsStr::new("tmp"))));
assert_eq!(components.next(), Some(Component::Normal(OsStr::new("foo.txt"))));
assert_eq!(components.next(), None)

fn iter(&self) -> Iter

Produce an iterator over the path's components viewed as OsStr slices.

Examples

use std::path::{self, Path};
use std::ffi::OsStr;

let mut it = Path::new("/tmp/foo.txt").iter();
assert_eq!(it.next(), Some(OsStr::new(&path::MAIN_SEPARATOR.to_string())));
assert_eq!(it.next(), Some(OsStr::new("tmp")));
assert_eq!(it.next(), Some(OsStr::new("foo.txt")));
assert_eq!(it.next(), None)

fn display(&self) -> Display

Returns an object that implements Display for safely printing paths that may contain non-Unicode data.

Examples

use std::path::Path;

let path = Path::new("/tmp/foo.rs");

println!("{}", path.display());

fn metadata(&self) -> Result<Metadata, Error>
1.5.0

Query the file system to get information about a file, directory, etc.

This function will traverse symbolic links to query information about the destination file.

This is an alias to fs::metadata.

Query the metadata about a file without following symlinks.

This is an alias to fs::symlink_metadata.

fn canonicalize(&self) -> Result<PathBuf, Error>
1.5.0

Returns the canonical form of the path with all intermediate components normalized and symbolic links resolved.

This is an alias to fs::canonicalize.

Reads a symbolic link, returning the file that the link points to.

This is an alias to fs::read_link.

fn read_dir(&self) -> Result<ReadDir, Error>
1.5.0

Returns an iterator over the entries within a directory.

The iterator will yield instances of io::Result<DirEntry>. New errors may be encountered after an iterator is initially constructed.

This is an alias to fs::read_dir.

fn exists(&self) -> bool
1.5.0

Returns whether the path points at an existing entity.

This function will traverse symbolic links to query information about the destination file. In case of broken symbolic links this will return false.

Examples

use std::path::Path;
assert_eq!(Path::new("does_not_exist.txt").exists(), false);

fn is_file(&self) -> bool
1.5.0

Returns whether the path is pointing at a regular file.

This function will traverse symbolic links to query information about the destination file. In case of broken symbolic links this will return false.

Examples

use std::path::Path;
assert_eq!(Path::new("./is_a_directory/").is_file(), false);
assert_eq!(Path::new("a_file.txt").is_file(), true);

fn is_dir(&self) -> bool
1.5.0

Returns whether the path is pointing at a directory.

This function will traverse symbolic links to query information about the destination file. In case of broken symbolic links this will return false.

Examples

use std::path::Path;
assert_eq!(Path::new("./is_a_directory/").is_dir(), true);
assert_eq!(Path::new("a_file.txt").is_dir(), false);