Trait bitflags::__core::prelude::v1::Default 1.0.0
[−]
[src]
pub trait Default {
fn default() -> Self;
}A trait for giving a type a useful default value.
A struct can derive default implementations of Default for basic types using
#[derive(Default)].
Examples
#[derive(Default)] struct SomeOptions { foo: i32, bar: f32, }
Required Methods
fn default() -> Self
Returns the "default value" for a type.
Default values are often some kind of initial value, identity value, or anything else that may make sense as a default.
Examples
Using built-in default values:
let i: i8 = Default::default(); let (x, y): (Option<String>, f64) = Default::default(); let (a, b, (c, d)): (i32, u32, (bool, bool)) = Default::default();
Making your own:
enum Kind { A, B, C, } impl Default for Kind { fn default() -> Kind { Kind::A } }
Implementors
impl<K, V, S> Default for HashMap<K, V, S> where K: Eq + Hash, S: BuildHasher + Defaultimpl Default for RandomStateimpl<T, S> Default for HashSet<T, S> where S: BuildHasher + Default, T: Eq + Hashimpl<T> Default for VecDeque<T>impl<T> Default for BinaryHeap<T> where T: Ordimpl<T> Default for LinkedList<T>impl<'a> Default for &'a CStrimpl Default for CStringimpl Default for OsStringimpl<'a> Default for &'a OsStrimpl Default for Condvarimpl<T> Default for Mutex<T> where T: Default + ?Sizedimpl<T> Default for RwLock<T> where T: Defaultimpl Default for AtomicBoolimpl<T> Default for AtomicPtr<T>impl Default for AtomicI8impl Default for AtomicU8impl Default for AtomicI16impl Default for AtomicU16impl Default for AtomicI32impl Default for AtomicU32impl Default for AtomicI64impl Default for AtomicU64impl Default for AtomicIsizeimpl Default for AtomicUsizeimpl<T> Default for Box<T> where T: Defaultimpl<T> Default for Box<[T]>impl Default for Stringimpl Default for SipHasherimpl<H> Default for BuildHasherDefault<H>impl<T> Default for Option<T>impl<T> Default for Rc<T> where T: Defaultimpl<T> Default for Weak<T>impl<T> Default for Vec<T>impl<T> Default for Cell<T> where T: Copy + Defaultimpl<T> Default for RefCell<T> where T: Defaultimpl<T> Default for UnsafeCell<T> where T: Defaultimpl<T> Default for Empty<T>impl Default for ()impl Default for boolimpl Default for charimpl Default for usizeimpl Default for u8impl Default for u16impl Default for u32impl Default for u64impl Default for isizeimpl Default for i8impl Default for i16impl Default for i32impl Default for i64impl Default for f32impl Default for f64impl<T> Default for PhantomData<T> where T: ?Sizedimpl<K, V> Default for BTreeMap<K, V> where K: Ordimpl<T> Default for BTreeSet<T> where T: Ordimpl<T> Default for Wrapping<T> where T: Defaultimpl<T> Default for [T; 32] where T: Defaultimpl<T> Default for [T; 31] where T: Defaultimpl<T> Default for [T; 30] where T: Defaultimpl<T> Default for [T; 29] where T: Defaultimpl<T> Default for [T; 28] where T: Defaultimpl<T> Default for [T; 27] where T: Defaultimpl<T> Default for [T; 26] where T: Defaultimpl<T> Default for [T; 25] where T: Defaultimpl<T> Default for [T; 24] where T: Defaultimpl<T> Default for [T; 23] where T: Defaultimpl<T> Default for [T; 22] where T: Defaultimpl<T> Default for [T; 21] where T: Defaultimpl<T> Default for [T; 20] where T: Defaultimpl<T> Default for [T; 19] where T: Defaultimpl<T> Default for [T; 18] where T: Defaultimpl<T> Default for [T; 17] where T: Defaultimpl<T> Default for [T; 16] where T: Defaultimpl<T> Default for [T; 15] where T: Defaultimpl<T> Default for [T; 14] where T: Defaultimpl<T> Default for [T; 13] where T: Defaultimpl<T> Default for [T; 12] where T: Defaultimpl<T> Default for [T; 11] where T: Defaultimpl<T> Default for [T; 10] where T: Defaultimpl<T> Default for [T; 9] where T: Defaultimpl<T> Default for [T; 8] where T: Defaultimpl<T> Default for [T; 7] where T: Defaultimpl<T> Default for [T; 6] where T: Defaultimpl<T> Default for [T; 5] where T: Defaultimpl<T> Default for [T; 4] where T: Defaultimpl<T> Default for [T; 3] where T: Defaultimpl<T> Default for [T; 2] where T: Defaultimpl<T> Default for [T; 1] where T: Defaultimpl<T> Default for [T; 0]impl<'a, T> Default for &'a [T]impl<'a, T> Default for &'a mut [T]impl<'a> Default for &'a strimpl Default for Errorimpl<A> Default for (A,) where A: Defaultimpl<A, B> Default for (A, B) where A: Default, B: Defaultimpl<A, B, C> Default for (A, B, C) where A: Default, B: Default, C: Defaultimpl<A, B, C, D> Default for (A, B, C, D) where A: Default, B: Default, C: Default, D: Defaultimpl<A, B, C, D, E> Default for (A, B, C, D, E) where A: Default, B: Default, C: Default, D: Default, E: Defaultimpl<A, B, C, D, E, F> Default for (A, B, C, D, E, F) where A: Default, B: Default, C: Default, D: Default, E: Default, F: Defaultimpl<A, B, C, D, E, F, G> Default for (A, B, C, D, E, F, G) where A: Default, B: Default, C: Default, D: Default, E: Default, F: Default, G: Defaultimpl<A, B, C, D, E, F, G, H> Default for (A, B, C, D, E, F, G, H) where A: Default, B: Default, C: Default, D: Default, E: Default, F: Default, G: Default, H: Defaultimpl<A, B, C, D, E, F, G, H, I> Default for (A, B, C, D, E, F, G, H, I) where A: Default, B: Default, C: Default, D: Default, E: Default, F: Default, G: Default, H: Default, I: Defaultimpl<A, B, C, D, E, F, G, H, I, J> Default for (A, B, C, D, E, F, G, H, I, J) where A: Default, B: Default, C: Default, D: Default, E: Default, F: Default, G: Default, H: Default, I: Default, J: Defaultimpl<A, B, C, D, E, F, G, H, I, J, K> Default for (A, B, C, D, E, F, G, H, I, J, K) where A: Default, B: Default, C: Default, D: Default, E: Default, F: Default, G: Default, H: Default, I: Default, J: Default, K: Defaultimpl<A, B, C, D, E, F, G, H, I, J, K, L> Default for (A, B, C, D, E, F, G, H, I, J, K, L) where A: Default, B: Default, C: Default, D: Default, E: Default, F: Default, G: Default, H: Default, I: Default, J: Default, K: Default, L: Defaultimpl<T> Default for Weak<T>impl<T> Default for Arc<T> where T: Defaultimpl Default for ReseedWithDefault