Enum bitflags::__core::sync::mpsc::TryRecvError 1.0.0
[−]
[src]
pub enum TryRecvError {
Empty,
Disconnected,
}1.0.0
This enumeration is the list of the possible reasons that try_recv could
not return data when called.
Variants
Empty | This channel is currently empty, but the sender(s) have not yet disconnected, so data may yet become available. | |
Disconnected | This channel's sending half has become disconnected, and there will never be any more data received on this channel |