Struct bitflags::__core::sync::mpsc::RecvError 1.0.0
[−]
[src]
pub struct RecvError;
An error returned from the recv function on a Receiver.
The recv operation can only fail if the sending half of a channel is
disconnected, implying that no further messages will ever be received.