Struct bitflags::__core::sync::MutexGuard1.0.0 [] [src]

#[must_use]
pub struct MutexGuard<'a, T> where T: 'a + ?Sized {
    // some fields omitted
}

An RAII implementation of a "scoped lock" of a mutex. When this structure is dropped (falls out of scope), the lock will be unlocked.

The data protected by the mutex can be access through this guard via its Deref and DerefMut implementations