Struct bitflags::__core::sync::WaitTimeoutResult 1.5.0
[−]
[src]
pub struct WaitTimeoutResult(_);
A type indicating whether a timed wait on a condition variable returned due to a time out or not.
Methods
impl WaitTimeoutResult