Struct ParseError
struct ParseError(_)
An error encountered while parsing flags from text.
Implementations
impl ParseError
fn invalid_hex_flag<impl fmt::Display: fmt::Display>(flag: impl Display) -> SelfAn invalid hex flag was encountered.
fn invalid_named_flag<impl fmt::Display: fmt::Display>(flag: impl Display) -> SelfA named flag that doesn't correspond to any on the flags type was encountered.
const fn empty_flag() -> SelfA hex or named flag wasn't found between separators.
impl Debug for ParseError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for ParseError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for ParseError
impl Freeze for ParseError
impl RefUnwindSafe for ParseError
impl Send for ParseError
impl Sync for ParseError
impl Unpin for ParseError
impl UnsafeUnpin for ParseError
impl UnwindSafe for ParseError
impl<T> Any for ParseError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ParseError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ParseError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ParseError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for ParseError
fn to_string(self: &Self) -> String
impl<T, U> Into for ParseError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ParseError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ParseError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>