Enum bitflags::__core::sync::TryLockError 1.0.0
[−]
[src]
pub enum TryLockError<T> {
Poisoned(PoisonError<T>),
WouldBlock,
}1.0.0
An enumeration of possible errors which can occur while calling the
try_lock method.
Variants
Poisoned | The lock could not be acquired because another thread failed while holding the lock. | |
WouldBlock | The lock could not be acquired at this time because the operation would otherwise block. |